pub struct Contact {Show 14 fields
pub id: String,
pub phone_number: String,
pub name: Option<String>,
pub email: Option<String>,
pub metadata: Option<HashMap<String, Value>>,
pub opted_out: Option<bool>,
pub line_type: Option<String>,
pub carrier_name: Option<String>,
pub line_type_checked_at: Option<String>,
pub invalid_reason: Option<String>,
pub invalidated_at: Option<String>,
pub user_marked_valid_at: Option<String>,
pub created_at: Option<String>,
pub updated_at: Option<String>,
}Fields
id: Stringphone_number: Stringname: Option<String>email: Option<String>metadata: Option<HashMap<String, Value>>opted_out: Option<bool>line_type: Option<String>Carrier-reported line type: mobile, voip, toll free, fixed line,
fixed line or mobile, pager, voicemail, shared cost, etc.
Populated after a carrier lookup.
carrier_name: Option<String>line_type_checked_at: Option<String>invalid_reason: Option<String>Auto-exclusion reason: landline, invalid_number, non_sms_capable.
Clear with contacts.mark_valid().
invalidated_at: Option<String>user_marked_valid_at: Option<String>When a user manually cleared an auto-flag on this contact. Carrier re-checks that would re-flag the contact as invalid respect this timestamp and leave the contact clean, so your manual decisions survive future lookups.
created_at: Option<String>updated_at: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Contact
impl<'de> Deserialize<'de> for Contact
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more